@@ -1,50 +1,49 @@
 #' Item and ability parameters estimation for dichotomous items
 #'
 #' @description This function estimates IRT item and ability parameters when all items are scored dichotomously.
-#' Based on Bock & Aitkin's (1981) marginal maximum likelihood and EM algorithm (EM-MML), this function incorporates several latent distribution estimation algorithms which could free the normality assumption on the latent variable.
-#' If the normality assumption is violated, application of these latent distribution estimation methods could reflect some features of the unknown true latent distribution,
+#' Based on Bock & Aitkin's (1981) marginal maximum likelihood and EM algorithm (EM-MML), this function provides several latent distribution estimation algorithms which could free the normality assumption on the latent variable.
+#' If the normality assumption is violated, application of these latent distribution estimation methods could reflect non-normal characteristics of the unknown true latent distribution,
 #' and, thus, could provide more accurate parameter estimates (Li, 2021; Woods & Lin, 2009; Woods & Thissen, 2006).
 #'
 #' @importFrom stats density nlminb
 #' @importFrom utils flush.console
 #'
-#' @param data A matrix of item responses where responses are coded as 0 or 1.
+#' @param data A matrix or data frame of item responses where responses are coded as 0 or 1.
 #' Rows and columns indicate examinees and items, respectively.
-#' @param model A vector that represents types of item characteristic functions applied to each item.
+#' @param model A scalar or vector that represents types of item characteristic functions.
 #' Insert \code{1}, \code{"1PL"}, \code{"Rasch"}, or \code{"RASCH"} for one-parameter logistic model,
 #' \code{2}, \code{"2PL"} for two-parameter logistic model,
 #' and \code{3}, \code{"3PL"} for three-parameter logistic model. The default is \code{"2PL"}.
 #' @param range Range of the latent variable to be considered in the quadrature scheme.
 #' The default is from \code{-6} to \code{6}: \code{c(-6, 6)}.
 #' @param q A numeric value that represents the number of quadrature points. The default value is 121.
-#' @param initialitem A matrix of initial item parameter values for starting the estimation algorithm
+#' @param initialitem A matrix of initial item parameter values for starting the estimation algorithm. The default value is \code{NULL}.
 #' @param ability_method The ability parameter estimation method.
 #' The available options are Expected \emph{a posteriori} (\code{EAP}) and Maximum Likelihood Estimates (\code{MLE}).
 #' The default is \code{EAP}.
 #' @param latent_dist A character string that determines latent distribution estimation method.
-#' Insert \code{"Normal"}, \code{"normal"}, or \code{"N"} to assume normal distribution on the latent distribution,
+#' Insert \code{"Normal"}, \code{"normal"}, or \code{"N"} for the normality assumption on the latent distribution,
 #' \code{"EHM"} for empirical histogram method (Mislevy, 1984; Mislevy & Bock, 1985),
-#' \code{"Mixture"} or \code{"2NM"} for the method of two-component Gaussian mixture distribution (Li, 2021; Mislevy, 1984),
+#' \code{"2NM"} or \code{"Mixture"} for using two-component Gaussian mixture distribution (Li, 2021; Mislevy, 1984),
 #' \code{"DC"} or \code{"Davidian"} for Davidian-curve method (Woods & Lin, 2009),
 #' \code{"KDE"} for kernel density estimation method (Li, 2022),
-#' and \code{"LLS"} for log-linear smoothing method (Casabianca, Lewis, 2015).
-#' The default value is set to \code{"Normal"} for the conventional normality assumption on latent distribution.
-#'
+#' and \code{"LLS"} for log-linear smoothing method (Casabianca & Lewis, 2015).
+#' The default value is set to \code{"Normal"} to follow the convention.
 #' @param max_iter A numeric value that determines the maximum number of iterations in the EM-MML.
 #' The default value is 200.
 #' @param threshold A numeric value that determines the threshold of EM-MML convergence.
 #' A maximum item parameter change is monitored and compared with the threshold.
 #' The default value is 0.0001.
-#' @param bandwidth A character value is needed when \code{"KDE"} is used for the latent distribution estimation.
-#' This argument determines which bandwidth estimation method is used for \code{"KDE"}.
-#' The default value is \code{"SJ-ste"}. See \code{\link{density}} for possible options.
-#' @param h A natural number less than or equal to 10 is needed when \code{"DC"} is used for the latent distribution estimation.
-#' This argument determines the complexity of Davidian curve.
+#' @param bandwidth A character value that can be used if \code{latent_dist = "KDE"}.
+#' This argument determines the bandwidth estimation method for \code{"KDE"}.
+#' The default value is \code{"SJ-ste"}. See \code{\link{density}} for available options.
+#' @param h A natural number less than or equal to 10 if \code{latent_dist = "DC" or "LLS"}.
+#' This argument determines the complexity of the distribution.
 #'
 #' @details
 #' \describe{
 #' \item{
-#' The probabilities for correct response (\eqn{u=1}) in one-, two-, and three-parameter logistic models can be expressed as follows;
+#' The probabilities for a correct response (\eqn{u=1})
 #' }{
 #' 1) One-parameter logistic (1PL) model
 #' \deqn{P(u=1|\theta, b)=\frac{\exp{(\theta-b)}}{1+\exp{(\theta-b)}}}
@@ -58,7 +57,7 @@
 #' }
 #'
 #' \item{
-#' The estimated latent distribution for each of the latent distribution estimation method can be expressed as follows;
+#' Latent distribution estimation methods
 #' }{
 #' 1) Empirical histogram method
 #' \deqn{P(\theta=X_k)=A(X_k)}
@@ -85,29 +84,21 @@
 #' }
 #' }
 #'
-#' @return This function returns a \code{list} which contains several objects:
+#' @return This function returns a \code{list} of several objects:
 #' \item{par_est}{The item parameter estimates.}
 #' \item{se}{The asymptotic standard errors for item parameter estimates.}
-#' \item{fk}{The estimated frequencies of examinees at each quadrature points.}
-#' \item{iter}{The number of EM-MML iterations required for the convergence.}
+#' \item{fk}{The estimated frequencies of examinees at quadrature points.}
+#' \item{iter}{The number of EM-MML iterations elapsed for the convergence.}
 #' \item{quad}{The location of quadrature points.}
 #' \item{diff}{The final value of the monitored maximum item parameter change.}
 #' \item{Ak}{The estimated discrete latent distribution.
-#' It is discrete (i.e., probability mass function) since quadrature scheme of EM-MML is used.}
-#' \item{Pk}{The posterior probabilities for each examinees at each quadrature points.}
-#' \item{theta}{The estimated ability parameter values. If \code{ability_method = "MLE"}, and if an examinee answers all or none of the items correctly, the function returns \eqn{\pm}\code{Inf}.}
+#' It is discrete (i.e., probability mass function) by the quadrature scheme.}
+#' \item{Pk}{The posterior probabilities of examinees at quadrature points.}
+#' \item{theta}{The estimated ability parameter values. If \code{ability_method = "MLE"}. If an examinee answers all or none of the items correctly, the function returns \eqn{\pm}\code{Inf}.}
 #' \item{theta_se}{The asymptotic standard errors of ability parameter estimates. Available only when \code{ability_method = "MLE"}.
 #' If an examinee answers all or none of the items correctly, the function returns \code{NA}.}
-#' \item{logL}{The deviance (i.e., -2\emph{log}L).}
-#' \item{density_par}{
-#' The estimated density parameters.
-#' If \code{latent_dist = "2NM"}, \code{prob} is the estimated \eqn{\pi = \frac{n_1}{N}} parameter of two-component Gaussian mixture distribution, where \eqn{n_1} is the estimated number of examinees who belong to the first Gaussian component and \eqn{N} is the total number of examinees;
-#' \code{d} is the estimated \eqn{\delta = \frac{\mu_2 - \mu_1}{\bar{\sigma}}} parameter of two-component Gaussian mixture distribution,
-#' where \eqn{\mu_1} is the estimated mean of the first Gaussian component,
-#' \eqn{\mu_2} is the estimated mean of the second Gaussian component,
-#' and \eqn{\bar{\sigma} = 1} is the standard deviation of the latent distribution; and
-#' \code{sd_ratio} is the estimated \eqn{\zeta = \frac{\sigma_2}{\sigma_1}} parameter of two-component Gaussian mixture distribution, where \eqn{\sigma_1} is the estimated standard deviation of the first Gaussian component, \eqn{\sigma_2} is the estimated standard deviation of the second Gaussian component (Li, 2021).
-#' Without loss of generality, \eqn{\mu_2 \ge \mu_1}, thus \eqn{\delta \ge 0}, is assumed.}
+#' \item{logL}{The deviance (i.e., -2log\emph{L}).}
+#' \item{density_par}{The estimated density parameters.}
 #' \item{Options}{A replication of input arguments and other information.}
 #'
 #'
@@ -133,19 +124,11 @@
 #' @export
 #'
 #' @examples
-#' \dontrun{
+#' \donttest{
 #' # A preparation of dichotomous item response data
 #'
-#' data <- DataGeneration(seed = 1,
-#'                        model_D = rep(1, 10),
-#'                        N=500,
-#'                        nitem_D = 10,
-#'                        nitem_P = 0,
-#'                        latent_dist = "2NM",
-#'                        d = 1.664,
-#'                        sd_ratio = 2,
-#'                        prob = 0.3)$data_D
-#'
+#' data <- DataGeneration(N=500,
+#'                        nitem_D = 10)$data_D
 #'
 #' # Analysis
 #'
@@ -360,7 +343,10 @@ IRTest_Dich <- function(data, model="2PL", range = c(-6,6), q = 121, initialitem
   }
 
   # ability parameter estimation
-  if(ability_method == 'EAP'){
+  if(is.null(ability_method)){
+    theta <- NULL
+    theta_se <- NULL
+  } else if(ability_method == 'EAP'){
     theta <- as.numeric(E$Pk%*%E$Xk)
     theta_se <- NULL
   } else if(ability_method == 'MLE'){
@@ -396,7 +382,7 @@ IRTest_Dich <- function(data, model="2PL", range = c(-6,6), q = 121, initialitem
          density_par = density_par,
          Options = Options # specified argument values
          ),
-    class = c("dich", "irtest", "list")
+    class = c("dich", "IRTest", "list")
     )
   )
 }
